/*--------------------------------------------------------------------*/
/*                          J P _ L W M o d                           */
/*                                                                    */
/* Kostenlose Programmbibliothek der Luftwiderstandsmodelle zu den    */
/* Bchern:                                                           */
/*                                                                    */
/* Jochem PEELEN  "Ballistik kleiner Kaliber: der Luftwiderstand"     */
/* ISBN 978-3-7748-1522-2, Books on Demand, Norderstedt 2017          */
/*                                                                    */
/* und:           "Air Drag in Small Arms Ballistics"                 */
/* ISBN 978-3-7375-7768-7  Verlag epubli GmbH, Berlin 2015            */
/*                                                                    */
/*                                                                    */
/* Stand 16 Okt 2015: 5 Modelle nach ETBS und 3 UNST-Versionen hinzu  */
/*       27 Nov 2015: ISBN der englischen Fassung ergnzt             */
/*   ADD 13 Dez 2015: 5 Lapua Modelle L_B557 ... L_N563 hinzu         */
/*   FIX 04 Nov 2016: Text SUBOUTINE -> REQUIRES in oOREXX 5.0.0      */
/*   ADD 19 Jan 2017: 4 ETBS-Modelle hinzu: 98D, 98DR, 7RN, HFB       */
/*   ADD 10 Apr 2017: 4 Modelle fr 4,6 mm hinzu                      */
/*   ADD 06 Mai 2017: Modell FLECHETTE hinzu                          */
/*   ADD 03 Aug 2017: Modell SU_1956 hinzu                            */
/*--------------------------------------------------------------------*/
parse source . aufruf .
if aufruf \= 'SUBROUTINE' & aufruf \= 'REQUIRES' then do /*FIX 04Nov16*/
     /*---------------------------------------------------------------*/
     /* Bei Aufruf aus der Kommandozeile nur die Version melden.      */
     /*---------------------------------------------------------------*/
     say 'REXX-Bibliothek der Luftwiderstandsmodelle - V4.13  Stand 2017-08-03'
     say 'Autor: Jochem Peelen'
     exit 0                                       /* Programm beenden */
     end
/*--------------------------------------------------------------------*/
/* Dem REXX-Interpreter die bentigte externe  Bibliothek mitteilen   */
/*--------------------------------------------------------------------*/
::REQUIRES 'rxmath' LIBRARY    /* mathematische Funktionen  RxCalc... */
/*--------------------------------------------------------------------*/
/*            L u f t w i d e r s t a n d s m o d e l l e             */
/*                                                                    */
/*   Dokumentation und Quellenangaben der Modelle im Buch enthalten   */
/*--------------------------------------------------------------------*/
::ROUTINE 2_4_CRH       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-92.62358720384098467+x*(1594.577550957187019+ ,
    x*(-12147.67597155918172+x*(54117.51370670866654+ ,
    x*(-156156.7325798464829+x*(305114.2387047083388+ ,
    x*(-409043.0836280461230+x*(371722.6851648406459+ ,
    x*(-219266.2984583665409+x*(75847.52155397174668+ ,
    x*-11689.64512269416988)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE 2_CRH         PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=67.56512224907262621+x*(-1241.122584933417803+ ,
    x*(10181.693026448259064+x*(-48711.17601393523001+ ,
    x*(150325.6808929851338+x*(-312399.6772982541748+ ,
    x*(442616.2769682066630+x*(-422237.5276205154654+ ,
    x*(259665.2025743315366+x*(-93013.35041348350690+ ,
    x*14746.83284012093799)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE 5_10_CRH      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(-54.93432697930666496+x*(-0.5335595246184897036+ ,
    x*(92.26528588240137375+x*(-40.62791309213310808+ ,
    x*4.842994452175985896))))/ ,
    (1.0+x*(-249.2979149770242618+x*(346.6498995097210200+ ,
    x*(-104.87003911329627862+x*9.094141370819902322))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE 8_16_CRH      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=RxCalcSqrt(x);
  y=(-0.1591675197762621764+x*(0.6078745515598974998+ ,
    x*(-0.7394461671969717268+x*0.2907575252936563219)))/ ,
    (1.0+x*(-4.124187102310612228+x*(6.726533833438987623+ ,
    x*(-5.082537467109435194+x*1.480252049144732497))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE BRL620_M2     PUBLIC
numeric digits 24
parse arg x
if x < 0.5 | x > 3.0 then return 0
y=(0.3570891213398587173+x*(-1.364494449247243078+ ,
  x*(2.016030775825761972+x*(-1.400954919494967091+ ,
  x*(0.4289572017417902286+x*-0.03620822395909164569)))))/ ,
  (1.0+x*(-3.579660677728002468+x*(4.864512602604130552+ ,
  x*(-2.987909024250569896+x*(0.7128196843865836297+ ,
  x*-0.008618725061651919604)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE BURGSDORFF    PUBLIC
numeric digits 24
parse arg x
if x < 0.76 | x > 3.0 then return 0
y=(0.3980893588495041178+x*(-0.8656996304926629970+ ,
  x*0.5070624248102300521))/ ,
  (1.0+x*(-1.961400274381096570+x*(1.092708461763160159+ ,
  x*-0.03417107626280892404)))
return y
/*--------------------------------------------------------------------*/
::ROUTINE CARTER_CUBE   PUBLIC
parse arg x
select
when x > 10 then y = 0
when x > 1.131 then do
     z = x + 0.35
     y = 2.1 * RxCalcExp(-1.16 * z) - 6.5 * RxCalcExp(-2.23 * z) + 1.67
     end
when x >= 0 then do
     y = 0.60 * x**2 + 1.04
     end
otherwise
     y = 0
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE CARTER_SPH    PUBLIC
parse arg x
select
when x > 10 then y = 0
when x > 0.722 then do
     z = x + 0.35
     y = 2.1 * RxCalcExp(-1.2 * z) - 8.9 * RxCalcExp(-2.2 * z) + 0.92
     end
when x >= 0 then do
     y = 0.45 * x**2 + 0.424
     end
otherwise
     y = 0
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE CETMEIWK      PUBLIC
numeric digits 24
parse arg x
select
when x < 0.87 then y = 0
when x > 2.58 then y = 0
otherwise
  n=1.0/x
  y=x*(1762.924240444267651+x*(-739.2848555240992190+ ,
    x*(196.4669076602199606+x*(-30.03874304249570914+ ,
    x*2.013999451288911118))))+ ,
    -2761.535311017023970+n*(2841.421646811005823+ ,
    n*(-1850.284177275306914+n*(691.7195291082694210+ ,
    n*-113.1337890723916018)))
  end
return y
/*--------------------------------------------------------------------*/
::ROUTINE CW_CONST      PUBLIC
return 1
/*--------------------------------------------------------------------*/
::ROUTINE DEMOGUE       PUBLIC
numeric digits 16
parse arg x
if x < 0 | x > 3.52 then y = 0   /* Originalbereich 0 bis 1200 m/s    */
else do
     x = x * 341                 /* angenommene Schallgeschwindigkeit */
     v1 = (x - 330) / 50         /* v' bei Haag                       */
     v2 = (x - 600) / 1E6        /* Ergnzung von Garnier             */
     zz = (v1 / 10)**8 * 0.0392  /* Zahl unter der Wurzel im Zhler   */
     zz = RxCalcPower(1+zz,0.25) /* Zhler                            */
     nn = v1**2 * 494 + 27226    /* Nenner                            */
     y  = ( 0.2550 + zz / nn * RxCalcArcTan(v1) * 60 ) * RxCalcPower(10,v2)
     end
return y * 1.6967
/*--------------------------------------------------------------------*/
::ROUTINE DUPUIS        PUBLIC
parse arg n , x
select
when x < 1 then y = 0
when x >= 5.624 then y = 0    /* Original log(x) = 0.75 -> M 5.623413 */
otherwise
     /*---------------------------------------------------------------*/
     /* Werte der Konstante DUPA aus Geschosskennzahl N:              */
     /*                                                               */
     /* dupa  = x - 0.54     fr n = 0.04  "moderne" Geschossformen   */
     /* dupa  = x - 0.64     fr n = 0.14  Mitte dazwischen           */
     /* dupa  = x - 0.74     fr n = 0.24  "alte" Geschossformen      */
     /*---------------------------------------------------------------*/
     dupa  = x - 0.5 - n
     duplg = 6.02559586E-2    /* Numerus zu Dezimal-Logarithmus -1.22 */
     dupex = RxCalcPower(10,-5.5* (x-1.94)**2)
     dupfb = 96000 * (dupa + duplg * (x - 2.05) * dupex)    /*  F(b)  */
     y     = dupfb / (341*x)**2                     /* cw = F(b)/v**2 */
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE DUPUIS_040    PUBLIC
parse arg x
return dupuis(0.04,x)
/*--------------------------------------------------------------------*/
::ROUTINE DUPUIS_140    PUBLIC
parse arg x
return dupuis(0.14,x)
/*--------------------------------------------------------------------*/
::ROUTINE DUPUIS_240    PUBLIC
parse arg x
return dupuis(0.24,x)
/*--------------------------------------------------------------------*/
::ROUTINE FMV_10PRJ     PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3.0 then y = 0
else do
  x=1.0/x
  y=3.933483198524140858+x*(-60.64479629153025386+ ,
    x*(409.8982021709020680+x*(-1508.278925492483559+ ,
    x*(3337.936488827744035+x*(-4562.888591577042490+ ,
    x*(3770.597041622625014+x*(-1725.128022798012384+ ,
    x*334.9721385628997534)))))))
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE FORTR_G6      PUBLIC
numeric digits 15
parse arg x
select
when x <  0 then return 0
when x <= 0.053 then y = 0.1003024
when x <= 0.233 then do
     y = 0.094823643+x*(0.2429313+x*(-3.3837+x*(15.539437+x*-24.126021)))
     end
when x <= 0.863 then do
     y = 0.11010627+x*(-0.1346965+x*(0.33635169+x*(-0.45739903+x*0.24588434)))
     end
when x <= 1.033 then do
     y = -118.32592+x*(515.93365+x*(-840.14262+x*(605.64056+x*-162.96801)))
     end
when x <= 1.240 then do
     y = -68.123779+x*(230.69799+x*(-292.13472+x*(164.38222+x*-34.68202)))
     end
when x <= 4.060 then do
     y = 0.14540528+x*(0.11561148+x*(-0.10352627+x*(0.026467183+x*-0.0022346898)))
     end
when x <= 4.445 then do
     y = -0.4897612+x*(0.62502782+x*(-0.24248594+x*(0.040170705+x*-0.002454022)))
     end
when x <= 5  then do
     y = 0.9908997 + 0.12062376 * x
     y = ( y**2 - 1 ) / x**2
     end
otherwise             /* Keine Obergrenze im Original; hier Mach > 5  */
     y = 0
     end
return y * 2.54648    /* Faktor aus Originalprogramm wandelt KD in cw */
/*--------------------------------------------------------------------*/
::ROUTINE GAVRE_G1      PUBLIC
numeric digits 24
parse arg x
select
when x > 3.22 then return 0
when x >= 1 then do
  x=1.0/x
  y=9.643474771325737891+x*(-167.4273256307191622+ ,
    x*(1365.933189048717764+x*(-6522.376849269575645+ ,
    x*(20113.53111232391926+x*(-41733.51081423913612+ ,
    x*(58982.08977819317478+x*(-56115.14246109480012+ ,
    x*(34437.75411500375614+x*(-12326.36268836564956+ ,
    x*1956.348432371557782)))))))))
    end
when x < 0 then y = 0
otherwise
  y=(0.2624092929613900648+x*(-0.9769147614852665834+ ,
    x*(1.434991181790803356+x*(-0.9825643824828423853+ ,
    x*0.2636748987370237020))))/ ,
    (1.0+x*(-3.185246721330823551+x*(3.790808542510387604+ ,
    x*(-2.003372271251125115+x*0.4011346275811857418))))
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE GP11          PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
y=(0.2280654594801330948+x*(-0.7119043240579108928+ ,
  x*(0.7991086079117213800+x*(-0.3742752235239873892+ ,
  x*0.06298568618385245130))))/ ,
  (1.0+x*(-2.899499048866713027+x*(3.063555185084700826+ ,
  x*(-1.375482009044981756+x*0.2246937172362194543))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE GP11_4102     PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
y=(0.1991961155873781949+x*(-0.6224874872715679854+ ,
  x*(0.8158616227069279338+x*(-0.4722123624251486206+ ,
  x*0.09859598020474006979))))/ ,
  (1.0+x*(-2.503400895509561114+x*(2.534083531665083864+ ,
  x*(-1.076427166937488024+x*(0.08235404500169613647+ ,
  x*0.03800947586705741058)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE GP11_K        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
y=(-5.159886973985823376+x*(4.593523586794029790+ ,
  x*(4.346314789412850115+x*(-4.690187960634667617+ ,
  x*1.085473006213859345))))/ ,
  (1.0+x*(-24.97882111198312405+x*(45.13436383956131588+ ,
  x*(-25.42171888353476080+x*4.743170967397175686))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE HODSOCK       PUBLIC
parse arg x
if x < 1 | x > 3.57 then return 0
hodms  = x * 341.376             /* Schallgeschwindigkeit 1120 feet/s */
hodfs  = hodms / 0.3048
hodlbf = RxCalcPower(hodfs-950,0.7) / 12.07474         /* Pound force */
/* Umrechnung des Hodsock-Werts in moderne Darstellung                */
hodn   = hodlbf * 0.4536 * 9.81                        /* Newton      */
y      = 2 * hodn / ( 1.223 * 0.0127**2 * 3.14159 * hodms**2 )
return y
/*--------------------------------------------------------------------*/
::ROUTINE KUTTERER      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(-0.3135867639095055713+x*(-1.464197599701875011+ ,
    x*(2.295602058049733026+x*(-0.4314769046312700421+ ,
    x*0.03533412207002286216))))/ ,
    (1.0+x*(-7.029618042445258058+x*(7.699089090818473630+ ,
    x*(-1.409964079591807169+x*0.1256462914184924767))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_AP485       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
x=1.0/x
y=-63.09747103046611508+x*(1139.635044438404258+ ,
  x*(-9066.494811101538812+x*(41964.99248145046400+ ,
  x*(-125111.6937505320999+x*(251129.4777792580336+ ,
  x*(-343898.2350633114759+x*(317471.1321435114621+ ,
  x*(-189228.0253941595425+x*(65814.68344077465630+ ,
  x*-10152.049387798708949)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_AP492       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(0.09202903712045180211+x*(-0.5361933882148762085+  ,
    x*(0.7465571469341111974+x*(-0.3478160986154444710+ ,
    x*0.05409642406465461834))))/ ,
    (1.0+x*(-3.213077989665686622+x*(3.478038853720992603+ ,
    x*(-1.462015565614756399+x*0.2165494631976715116))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_AP529       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(0.3268191956291358358+x*(-0.6891256741780207512+ ,
    x*(0.5148360841639934656+x*-0.1544511961763167102)))/ ,
    (1.0+x*(-2.150683647065112661+x*(1.595778603531396882+ ,
    x*(-0.4206493105707800308+x*-0.03066433179298572822))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_AP529N      PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
y=(0.5103311522187531726+x*(-1.109398023004883972+ ,
  x*(0.8268731528624911546+x*(-0.2580397618769446753+  ,
  x*0.02871263278077424068))))/ ,
  (1.0+x*(-1.875241246120590262+x*(0.9696912635857520322+ ,
  x*(-0.02138727159179679543+x*(-0.09421613742816226855+ ,
  x*0.01661288450817102536)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_API526      PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=1.0/x
y=-177.0477566199064266+x*(3150.902594834349862+    ,
  x*(-24790.97510289766624+x*(113701.3449388285900+ ,
  x*(-336699.1755640810030+x*(672953.4936272397862+ ,
  x*(-919800.5483975260056+x*(849330.0088186667372+ ,
  x*(-507289.0892744311177+x*(177054.9281613432578+ ,
  x*-27433.46997691597335)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_B408        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(0.7221719083367394205+x*(-0.8175565059296941970+ ,
    x*(0.02598333250628303163+x*(0.02305891365409091443+ ,
    x*-0.003046167260292254164))))/ ,
    (1.0+x*(-0.5829913527327708283+x*(-0.7493969886738860082+ ,
    x*(0.2106949624214000220+x*-0.01861881062629305581))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_B466        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(1.164963668258486664+x*(-2.649633456287827593+ ,
    x*(1.676573095096496008+x*(-0.07535472665544274930+ ,
    x*(-0.1275252456607777918+x*0.02269682602278385399)))))/ ,
    (1.0+x*(-0.8177049181104749084+x*(-2.257189805726280321+ ,
    x*(3.034288679367299426+x*(-1.057535098555158653+ ,
    x*0.1219139328851515074)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_B476        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-367.0447083698005892+x*(6422.032532427416904+ ,
    x*(-49634.82817601000088+x*(223309.7671980829715+ ,
    x*(-647904.5979997979727+x*(1267422.502064062697+ ,
    x*(-1694010.606018912816+x*(1528612.849692040462+ ,
    x*(-891847.6621815288449+x*(304003.0526163382951+ ,
    x*-46004.99099879609588)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_BULLEXN     PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
x=1.0/x
y=-347.6664077602844978+x*(6009.391635788326032+ ,
  x*(-45925.70090680277797+x*(204444.0811555695923+ ,
  x*(-587194.0821540676584+x*(1137447.118645507376+ ,
  x*(-1505728.919803867647+x*(1345839.122105393687+ ,
  x*(-777810.9147423066613+x*(262643.2495734851684+ ,
  x*-39375.36904237107416)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_BULLEX2     PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
x=1.0/x
y=11.42383013048440300+x*(-154.7696724324394430+    ,
  x*(900.2873481209728658+x*(-2902.839503680666206+ ,
  x*(5703.284198140937906+x*(-7006.246625802446331+ ,
  x*(5262.077682812129934+x*(-2210.621160927279130+ ,
  x*397.7450857458110432)))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_D166        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-15.82807029532998343+x*(260.5604403158142976+ ,
    x*(-1841.344712904492807+x*(7413.702223559332450+ ,
    x*(-18701.27178713224629+x*(30693.04597753261519+ ,
    x*(-32840.99383718910528+x*(22135.37052740147736+ ,
    x*(-8543.932148409304690+x*1441.110391867266702))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_D46         PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-95.06065781626885289+x*(1631.938074557961889+ ,
    x*(-12409.07675037328926+x*(55190.99828783312930+ ,
    x*(-159072.3527566360198+x*(310637.1770969676790+ ,
    x*(-416442.9209068032446+x*(378600.6328271881172+ ,
    x*(-223460.4002988655172+x*(77343.36338362886670+ ,
    x*-11923.93130743216673)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_E539        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=x**2
y=(-17.54708976281730139+x*(107.6735988757233376+ ,
  x*(-93.31088128522396317+x*2.546883870703353652)))/ ,
  (1.0+x*(150.3020485177288083+x*(-153.0937682635822447+ ,
  x*0.2059253415965718422)))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_G490        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-52.79128124072294909+x*(1029.936770863979880+ ,
    x*(-8724.914087456836989+x*(42540.32722771577908+ ,
    x*(-132475.2033497773831+x*(275942.1949669572500+ ,
    x*(-390145.3861376322427+x*(370383.0411617344898+ ,
    x*(-226320.3359077382046+x*(80494.90166232225976+ ,
    x*-12671.37397227333997)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB422       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(0.9417005200416132138+x*(-3.329626691207752734+ ,
    x*(4.580305591256211184+x*(-3.049773452032969451+ ,
    x*(0.9785459820993893259+x*-0.1214806748269962034)))))/ ,
    (1.0+x*(-2.640579612454213863+x*(1.689625905545922440+ ,
    x*(1.141000062755040317+x*(-1.886175027009154715+ ,
    x*(0.8126173401965383864+x*-0.1172582990073071858))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB432       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-35.07817442389885110+x*(499.4620510934895754+ ,
    x*(-3024.198835364586589+x*(10236.528146131614222+ ,
    x*(-21184.52516020747419+x*(27480.89395528996417+ ,
    x*(-21853.04326663860410+x*(9753.556178648152384+ ,
    x*-1873.212826940538461)))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB458       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(0.3704307037541203085+x*(-1.253960189877095133+ ,
    x*(1.457750615027312575+x*(-0.6791324124587403373+ ,
    x*0.1098596161920435433))))/ ,
    (1.0+x*(-2.901175737527091542+x*(2.618529072181626681+ ,
    x*(-0.5504609878485296068+x*(-0.2323673789566305970+ ,
    x*0.07853140556832358551)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB478       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(0.2877874756274241432+x*(-0.8808882458609450265+ ,
    x*(0.8753282189906053878+x*(-0.2796407182567747468+ ,
    x*(0.03270772832429366701+x*-0.0007851516619315980926)))))/ ,
    (1.0+x*(-2.763302546934382510+x*(2.547122218238619767+ ,
    x*(-0.7527671412489936420+x*(0.07468444714071790440+ ,
    x*-0.0002519040854100335615)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB488       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(0.5494127903833226111+x*(-0.9782086685836295640+ ,
    x*(0.2878607651041510787+x*(0.1415742736667296106+ ,
    x*-0.0006241140796447388320))))/ ,
    (1.0+x*(-1.344821432849680381+x*(-0.3986197769633240375+ ,
    x*(0.7601946182002232426+x*(-0.01860020916110540662+ ,
    x*0.001897123270487909496)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB491       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(0.5993358347916636469+x*(-1.044749220944775678+ ,
    x*(0.5186658540013865396+x*-0.08090669327930588642)))/ ,
    (1.0+x*(-1.246576002242332148+x*(-0.01300360967760485018+ ,
    x*(0.3065075157492743856+x*-0.06970829608294890591))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB493       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-90.93917170849473291+x*(1719.278547220406822+ ,
    x*(-14252.07528662420513+x*(68398.69846992617986+ ,
    x*(-210558.9202079155186+x*(434760.0699714886541+ ,
    x*(-610275.7963758561494+x*(575568.8482482669637+ ,
    x*(-349385.3164048286825+x*(123387.4421589380031+ ,
    x*-19270.87080012998054)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB501       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  n=1.0/x
  y=x*(-5209.435388080752502+x*(1986.667889547995302+ ,
    x*(-476.5569449500713092+x*(65.28949579408013503+ ,
    x*-3.895279033164741872))))+ ,
    8905.846764261776896+n*(-9920.512263959518488+ ,
    n*(6941.661552843799873+n*(-2767.132123915216772+ ,
    n*478.5173640690640044)))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB527       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(-20.01708611938243245+x*(8.919158452787010642+ ,
    x*(16.93786611414336571+x*(-6.065743391205435342+ ,
    x*2.364347994916481831))))/ ,
    (1.0+x*(-85.68461311653024081+x*(121.4717166198440127+ ,
    x*(-41.45662194059186570+x*10.042193117845809805))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB528       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(-6.362265256688032156+x*(20.76323456461391881+ ,
    x*(-16.64247969868289795+x*(-4.229298219552507483+ ,
    x*6.505496721425483394))))/ ,
    (1.0+x*(-7.153390849986598700+x*(38.55333746595434814+ ,
    x*(-61.45684268481122502+x*29.17024649116296985))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB541       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-73.87099640151075382+x*(1164.605770193750733+ ,
    x*(-7989.515036576296176+x*(31398.35229232982972+ ,
    x*(-77864.96822468983570+x*(126357.0919336977646+ ,
    x*(-134191.9655301285089+x*(89956.79476568955186+ ,
    x*(-34552.19944799635942+x*5796.099919486724206))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB543       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=1.0/x
y=-122.1922138809333632+x*(2318.925431893344420+    ,
  x*(-19265.28709300362605+x*(92524.47920569139736+ ,
  x*(-284770.4331361608771+x*(587559.0949768205834+ ,
  x*(-823935.4634332331650+x*(776227.3017817470884+ ,
  x*(-470677.8157573233603+x*(166050.7584580488264+ ,
  x*-25908.95312843329787)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB546       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=1.0/x
y=-116.4386546362070289+x*(2094.805171868561731+    ,
  x*(-16555.09385020067606+x*(75833.21004052225093+ ,
  x*(-223151.5228603442201+x*(441379.0595868531550+ ,
  x*(-595158.5628344305914+x*(541021.7787154559399+ ,
  x*(-317766.7884442968786+x*(109041.0223713778598+ ,
  x*-16621.16114222262168)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB547       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=1.0/x
y=-12.86423082479581875+x*(195.3301424348849058+     ,
  x*(-1256.190408081725556+x*(4534.223933712541008+  ,
  x*(-10043.228166496799739+x*(14045.31898529926180+ ,
  x*(-12236.97482458614048+x*(6232.228962760287710+  ,
  x*(-1572.770018739948452+x*115.2826892143151892))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB550       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=1.0/x
y=-30.06319610557428090+x*(431.9269607118115226+    ,
  x*(-2641.012230758973905+x*(9036.268380966046506+ ,
  x*(-18913.39633727503765+x*(24820.76582519373855+ ,
  x*(-19969.07538948383960+x*(9016.051302535915276+ ,
  x*-1751.128207863707363)))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB551       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
y=(0.5159060484568687089+x*(-0.9669501182733904980+       ,
  x*(0.5409256965281038404+x*-0.09580678748445607932)))/  ,
  (1.0+x*(-1.579204139115454467+x*(0.4837924247513697026+ ,
  x*(0.1337745117271167518+x*-0.05699833744260674983))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB553       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
y=(98.60446010205001153+x*(-135.7019537941042678+        ,
  x*(-73.05511514060796327+x*(141.3538101716470311+      ,
  x*-30.79096230834412693))))/                           ,
  (1.0+x*(438.5986141984469446+x*(-1065.779135126547931+ ,
  x*(763.3410987174080013+x*-135.8744001091446057))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_GB554       PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=x**2
y=(16.67741339995536333+x*(-89.52410047455736568+         ,
  x*(-10.478901542898009172+x*91.12326349075660982)))/    ,
  (1.0+x*(-97.24579878280127418+x*(-173.7386076983549907+ ,
  x*(283.4885607913731396+x*10.160594283439478184))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N505        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(-12.43208418876756914+x*(43.08203159021414176+ ,
    x*(-46.14523522280862830+x*(18.19868986457818050+ ,
    x*-2.808790215422485650))))/ ,
    (1.0+x*(16.26313203695130345+x*(-24.99044244004555903+ ,
    x*(7.808912655547337082+x*(0.03835721212063656721+ ,
    x*-0.3573172259468755372)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N508        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=5.151970972143209168+x*(-66.90667025554184092+ ,
    x*(369.3414948404154803+x*(-1070.825421603970693+ ,
    x*(1795.929680707219079+x*(-1755.955219320338952+ ,
    x*(930.3242940897696301+x*-206.6892116260590927))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N518        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  y=(-0.7733382000340459152+x*(3.119914727192579886+ ,
    x*(-4.576970941629422460+x*(3.067926757321965146+ ,
    x*(-0.9431581938494438517+x*0.10440969228101596458)))))/ ,
    (1.0+x*(-3.021693481397615623+x*(4.411381724150524510+ ,
    x*(-4.076356410203667182+x*(2.254249201565771400+ ,
    x*(-0.6369953642611381472+x*0.06602288056458990959))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N522        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-250.8635780280757994+x*(4315.237151860066870+ ,
    x*(-32808.85228902213827+x*(145343.1394205584421+ ,
    x*(-415626.5934241975308+x*(802273.9624771404188+ ,
    x*(-1059531.848449658330+x*(946111.8127999035547+ ,
    x*(-547103.0867621705670+x*(185133.1243842093390+ ,
    x*-27855.65668510203057)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_S374        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=RxCalcLog(x)
  y=(0.4470018725248683345+x*(70.11863030378697232+ ,
    x*(43.20190173438394884+x*(-570.9779104388353490+ ,
    x*544.4513665705958024))))/ ,
    (1.0+x*(147.5819247962424718+x*(-156.7853061802033377+ ,
    x*(23.51506124859942234+x*(-868.6577243064213892+ ,
    x*1108.494470692303973)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_S405        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(856.2201770074041855+x*(-1745.438925153043462+ ,
    x*(659.8486189977632090+x*(-271.6324594740947571+ ,
    x*(463.7331100817757204+x*40.21473232575939217)))))/ ,
    (1.0+x*(120.4919015952400414+x*(-1046.742880773425057+ ,
    x*(178.2353702484227082+x*(535.8324893321846614+ ,
    x*217.9221062639183170)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_S538        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=1.0/x
y=-25.22535731088104929+x*(496.9686484917789812+    ,
  x*(-4282.472300655518611+x*(21413.07125031263472+ ,
  x*(-68730.53378444236602+x*(148079.5606565284391+ ,
  x*(-217079.0294399894575+x*(214007.8682916421282+ ,
  x*(-135905.1501603722910+x*(50242.45191852267552+ ,
  x*-8217.083431426473271)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE LOWRY         PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 5 then return 0
y=0.2865034409306163012+x*(0.3590440621460527906+ ,
  x*(-0.06111482097670695808+x*6.003346279995919700E-06))
return y
/*--------------------------------------------------------------------*/
::ROUTINE LW2           PUBLIC
numeric digits 24
parse arg x
select
when x > 10 then return 0
when x > 3  then do
  y=(0.1541000894757925823+x*(-0.1658542278166977874+ ,
    x*0.03976787563284074831))/ ,
    (1.0+x*(-0.9242818651270250957+x*(0.2009743012745450724+ ,
    x*0.0008274757633139348755)))
    end
when x > 1 then do
  x=1.0/x
  y=-26.83868218918426433+x*(486.2443663821744874+ ,
    x*(-3870.764019712625350+x*(17960.81123270397844+ ,
    x*(-53779.90298969062416+x*(108626.0293708331145+ ,
    x*(-149943.4249986875477+x*(139721.1256478781723+ ,
    x*(-84144.02531446903221+x*(29584.86404016550386+ ,
    x*-4613.723652378179638)))))))))
    end
when x > 0.1 then do
  x=x**2
  y=(0.2318935779316389660+x*(-0.1084502729318193024+ ,
    x*(-0.9272515592275897638+x*(1.259228270035115398+ ,
    x*-0.4533246194215981160))))/ ,
    (1.0+x*(0.4132863269359642027+x*(-6.767423538260920920+ ,
    x*(8.316003243770980394+x*-2.956554934518581713))))
    end
when x < 0 then y = 0
otherwise
    y = 0.2300
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE M855_WEIN     PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=92.61840106457021242+x*(-1682.321480988332258+ ,
    x*(13529.51812084909095+x*(-63292.54021127352932+ ,
    x*(190818.7095493108026+x*(-387535.5854614123848+ ,
    x*(537183.9142150655187+x*(-502114.9837264718177+ ,
    x*(303067.5358271206786+x*(-106728.5588972639860+ ,
    x*16662.09096248128630)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE MAYEVSAB      PUBLIC
parse arg x
x = x * 340                             /* Umwandlung Machzahl in m/s */
select
when x > 1020 then return 0                             /* ungltig   */
when x > 800 then  y = 11.6 * RxCalcPower(x,-0.45)      /* Mach 2.353 */
when x > 550 then  y = 4.256 * RxCalcPower(x,-0.3)      /* Mach 1.618 */
when x > 419 then  y = 0.641                            /* Mach 1.232 */
when x > 375 then  y = 1.530E-3 * x                     /* Mach 1.103 */
when x > 295 then  y = 1.091E-8 * x**3                  /* Mach 0.868 */
when x > 240 then  y = 9.491E-4 * x                     /* Mach 0.706 */
when x < 0   then  y = 0                                /* ungltig   */
otherwise
     y = 0.228
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_G2      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(-6.160658393996984800+x*(2.820328217616511085+ ,
    x*(10.69748903240173316+x*(-9.534232642678221755+ ,
    x*(3.353923910807589567+x*-0.06746136829018549078)))))/ ,
    (1.0+x*(-37.76620666639196704+x*(73.31929288860814246+ ,
    x*(-46.08688920856662206+x*(12.33853542375282550+ ,
    x*-0.01955018516576194150)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_G5      PUBLIC
numeric digits 24
parse arg x
select
when x > 3 then return 0
when x > 1 then do
  y=-57922.34840399638780+x*(467903.3544931592372+ ,
    x*(-1747153.136321100644+x*(4000554.553901585543+ ,
    x*(-6282629.537880878988+x*(7168867.641406370700+ ,
    x*(-6140938.062418622337+x*(4021918.268077364853+ ,
    x*(-2030864.721708681286+x*(790782.0838991993572+ ,
    x*(-235549.4924191586910+x*(52719.34275377844420+ ,
    x*(-8583.782138192065343+x*(960.0390846836013787+ ,
    x*(-65.96413696760672235+x*2.099421893229331622))))))))))))))
    end
when x < 0 then y = 0
otherwise
  x=x**2
  y=(0.1712303147957863777+x*(3.291614366985542092+ ,
    x*(-13.66434332768145629+x*(21.24735462237354639+ ,
    x*(-15.58297657649327841+x*4.616174674765874826)))))/ ,
    (1.0+x*(18.15545196778855794+x*(-65.19945921184965710+ ,
    x*(83.87389487698775232+x*(-49.30725312326862246+ ,
    x*11.71136401280276144)))))
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_G6      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(4.106219489632053607+x*(-4.193815223343562457+ ,
    x*(-3.484694134568835955+x*(2.636811568174961422+ ,
    x*(0.8102987145470410902+x*0.1566153992644075619)))))/ ,
    (1.0+x*(14.16217375331297800+x*(-33.71436697634669010+ ,
    x*(20.53782384171963842+x*(-3.179999744234620813+ ,
    x*1.281763476389138621)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_G7      PUBLIC
numeric digits 24
parse arg x
select
when x > 5 then return 0
when x > 3 then do
  y=(0.7333680835490764220+x*(-0.5053094170904133992+ ,
    x*0.09171666824441332986))/ ,
    (1.0+x*(0.03290629298291932468+x*(-0.3715087505347671289+ ,
    x*0.08969663966452309314)))
    end
when x > 1 then do
  y=(0.4130458522387382240+x*(-1.029906977769072031+ ,
    x*(0.8872345368314360788+x*(-0.2381615033981236447+ ,
    x*(-0.08883025739730379260+x*(0.06685640597598432839+ ,
    x*-0.01125271157431608045))))))/ ,
    (1.0+x*(-2.920434945370859767+x*(3.705840614188710181+ ,
    x*(-2.889908524183490874+x*(1.592670510865649768+ ,
    x*(-0.6332032573042022046+x*(0.1613117552039123018+ ,
    x*-0.01894354177750031819)))))))
    end
when x > 0.6 then do
  x=x**2
  y=(0.1168816723376939229+x*(-0.4707205446878821543+ ,
    x*(0.7191484160430593656+x*(-0.4942963941510494890+ ,
    x*0.1290468492613475971))))/ ,
    (1.0+x*(-4.095112211401145746+x*(6.469447010986273193+ ,
    x*(-4.815262858959259524+x*(1.601426377254975302+ ,
    x*-0.1603405515241812870)))))
    end
when x < 0 then y = 0
otherwise
    y = 0.1194
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_G8      PUBLIC
numeric digits 24
parse arg x
select
when x > 5 then return 0
when x > 3 then do
  x=x**2
  y=1.069073245391230906+x*(-0.3970341797220321903+ ,
    x*(0.08990690612294759983+x*(-0.01194195156448772177+ ,
    x*(0.0009796918548308937872+x*(-5.036636204003641572E-05+ ,
    x*(1.582293279729621877E-06+x*(-2.779475921204296194E-08+ ,
    x*2.093207284302343393E-10)))))))
    end
when x > 1 then do
  x=1.0/x
  y=-38.01006560860049698+x*(688.1842161584603474+ ,
    x*(-5503.847396701692064+x*(25703.21487511708718+ ,
    x*(-77569.95143469939734+x*(158135.0137036582699+ ,
    x*(-220656.0148901797963+x*(208212.0571370223122+ ,
    x*(-127224.6666489792752+x*(45482.60887903671083+ ,
    x*-7228.181572247109776)))))))))
    end
when x > 0.75 then do
  y=(0.1703416658392784926+x*(-0.7219896990038453487+ ,
    x*(1.150207572776042474+x*(-0.8162711033406978676+ ,
    x*0.2177306943496193855))))/ ,
    (1.0+x*(-4.573147945301075594+x*(8.202767297675140035+ ,
    x*(-7.155444089730863792+x*(2.994335652299681466+ ,
    x*-0.4684638878631133106)))))
    end
when x < 0 then y = 0
otherwise
    y = 0.2103
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_M2      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=-16.69245281406794972+x*(274.2144959426515882+ ,
    x*(-1943.888449541420940+x*(7888.273958461454674+ ,
    x*(-20140.86336615584865+x*(33538.58774122479941+ ,
    x*(-36413.44793752177419+x*(24848.79644667989200+ ,
    x*(-9667.294255603638162+x*1632.675820571905940))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE MCCOY_SPH     PUBLIC
numeric digits 24
parse arg x
select
when x > 4 then return 0
when x > 3 then do
  y=416.6222594744424970+x*(-713.8903876933008193+ ,
    x*(509.7437806208233356+x*(-193.6701473204890071+ ,
    x*(41.29215227850820635+x*(-4.684341156988470874+ ,
    x*0.2209059104017739276)))))
    end
when x > 1 then do
  x=x**2
  y=(0.6877636976997115112+x*(-1.696010628232187425+ ,
    x*(2.137029585388956784+x*(-1.305236402240979894+ ,
    x*0.3074975380178317696))))/ ,
    (1.0+x*(-2.227847888392789849+x*(2.451624418524378926+ ,
    x*(-1.368502934664643630+x*(0.3040630327525667735+ ,
    x*0.001649043346681344225)))))
    end
when x > 0 then do
  y=(0.4659304087228019485+x*(-2.526576170762959044+ ,
    x*(5.340563384332880570+x*(-5.345699568793234636+ ,
    x*(2.310604101170014538+x*-0.1855462097717607737)))))/ ,
    (1.0+x*(-5.556785433312223473+x*(12.26159815152720415+ ,
    x*(-13.36859863402718609+x*(7.079906875189299008+ ,
    x*-1.343294075141921407)))))
    end
otherwise
    y = 0
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE NAVPG         PUBLIC
parse arg x
select
when x < 1.0 | x > 3.22 then return 0
when x < 1.47 then do
     y = RWS_1943(x) * 0.827069
     end
otherwise
npgms = x * 341.019    /* Mach -> m/s fr Schallgeschw. bei 16 Grad C */
npgn  = -177.7 + 0.868 * npgms + 0.000142 * npgms**2       /* Pond    */
npgn  = npgn * 0.00981                      /* FIX 19.06.13   Newton  */
y     = 2 * npgn / ( 1.215 * 0.00391**2 * 3.14159 * npgms**2 )
end
return y
/*--------------------------------------------------------------------*/
::ROUTINE NL_1898       PUBLIC
parse arg x
x = x * 340.89              /* Schallgeschwindigkeit fr NL Luftdaten */
select
when x > 1023 then return 0 /* Original nur bis 1000 m/s   Mach 3.001 */
when x > 700  then y = 0.68951           /* 1.4432*0.477765   M 2.053 */
when x > 500  then y = 0.0610727 * RxCalcPower(x,0.37)     /* M 1.467 */
when x > 400  then y = 0.1457818 * RxCalcPower(x,0.23)     /* M 1.173 */
when x > 350  then y = 1.0009387E-5 * RxCalcPower(x,1.83)  /* M 1.027 */
when x > 300  then y = 1.05644735E-8 * x**3                /* M 0.880 */
when x > 200  then y = 0.01646839 * RxCalcSqrt(x)          /* M 0.587 */
otherwise
     y = 0.232898
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE POWER_3_2     PUBLIC
parse arg x
if x >= 1 then y = 0.491 / RxCalcSqrt(x)
else y = 0
return y
/*--------------------------------------------------------------------*/
::ROUTINE RWS_1943      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=x**2
  y=(0.09332905206953267436+x*(0.09718637682713191537+ ,
    x*(-0.4666215514409131136+x*(0.2905854778839679862+ ,
    x*(0.02550358501719623030+x*-0.001301730809490228871)))))/ ,
    (1.0+x*(-1.796058213438954456+x*(0.9481437011000145107+ ,
    x*(-0.2843439891515613418+x*(0.2321564609019918265+ ,
    x*-0.009919463045270418305)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE S_CRANZ       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
y=-62042.56840709659286+x*(515874.4441816542098+ ,
  x*(-1981138.844863920812+x*(4661546.680875018452+ ,
  x*(-7516096.985918396994+x*(8797273.880537624768+ ,
  x*(-7722861.940936261134+x*(5178676.814122112705+ ,
  x*(-2674877.705143069487+x*(1064424.058867817092+ ,
  x*(-323726.1238186525768+x*(73911.90026350736156+ ,
  x*(-12265.75377048566185+x*(1397.050221165828163+ ,
  x*(-97.67677195639687173+x*3.160927747671521094))))))))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE SCHAPIRO      PUBLIC
numeric digits 24
parse arg x
if x < 0 | x > 5 then return 0
y=(0.1050947595606054188+x*(-0.3780446206819885623+ ,
  x*(0.5508351646706010422+x*(-0.3870301672628966400+ ,
  x*0.1096131658802077494))))/ ,
  (1.0+x*(-3.297748027884340283+x*(4.188924688345712800+ ,
  x*(-2.379907789131361111+x*(0.4219185536964883544+ ,
  x*0.07009671549341437782)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE SIACCI        PUBLIC
parse arg x
select
when x > 3.52  then cw = 0             /* Siacci-Obergrenze: 1023 m/s */
when x > 0.293 then do
     x = x * 341                       /* Mach --> m/s                */
     y = RxCalcSqrt((0.1648*x - 47.95)**2 + 9.6)
     cw = (0.2002*x - 48.05 + y + ,
        (0.0442*x*(x-300) / (371 + (x/200)**10))) / x**2 * 2111.5
     end
when x < 0 then y = 0                 /* auerhalb Gltigkeitsbereich */
otherwise
     cw = 0.255366                     /* < 100 m/s mit konstantem cw */
     end
return cw
/*--------------------------------------------------------------------*/
::ROUTINE SU_1943       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
  x=1.0/x
  y=29.32065783164675716+x*(-505.0589679827915800+ ,
    x*(3882.998736652664447+x*(-17406.68191642126464+ ,
    x*(50407.47652314319832+x*(-98541.98871528106557+ ,
    x*(131734.3998268527088+x*(-118953.2363494592725+ ,
    x*(69458.49982489417192+x*(-23690.39672193077737+ ,
    x*3584.992320152862640)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE UK_1910       PUBLIC
parse arg x
x = x * 1.12                        /* Umrechnung Mach in ft/s / 1000 */
ukms = x * 304.8                    /* Umrechnung ft/s / 1000  in m/s */
select /* x = mach*1.12 */
when x > 4.99 then return 0         /* auerhalb Gltigkeitsbereich   */
when x > 4.00 then y = 213.316 * RxCalcPower(x,1.45)     /* > M 3.571 */
when x > 2.60 then y = 157.243 * RxCalcPower(x,1.67)     /* > M 2.321 */
when x > 2.00 then y = 184.976 * RxCalcPower(x,1.5)      /* > M 1.786 */
when x > 1.46 then y = 150.247 * RxCalcPower(x,1.8)      /* > M 1.304 */
when x > 1.19 then y =  95.408 * x**3                    /* > M 1.063 */
when x > 1.04 then y =  52.354 * RxCalcPower(x,6.45)     /* > M 0.929 */
when x > 0.84 then y =  59.939 * x**3                    /* > M 0.750 */
when x >= 0.1 then y =  46.957 * RxCalcPower(x,1.6)
otherwise
     return 0                       /* auerhalb Gltigkeitsbereich   */
     end
/* Formelresultat p*g umrechnen in Newton und von da aus in cw        */
ukn    = y * 0.13825728                                   /* lbs -> N */
y      = 2 * ukn / ( 1.223 * 0.0127**2 * 3.14159 * ukms**2 )
return y
/*--------------------------------------------------------------------*/
::ROUTINE UK_1940       PUBLIC
parse arg x
select
when x < 0 then y = 0
when x < 1 then do
     expon = -2879.83545 * RxCalcPower(1.04233-x,3.147248112)
     y     = 0.335109 + 0.363205393 * RxCalcExp(expon)
     end
when x < 3.321 then do         /* 3720 fps im Original ab 1945        */
     f.1  =  2.1368774 / x**50
     f.2  = -6.829298  / x**45
     f.3  =  7.644594  / x**40
     f.4  = -3.470684  / x**35
     f.5  =  0.422137  / x**30
     f.6  =  1.07134
     f.7  = -0.37435 * x
     f.8  =  0.05125 * x**2
     f.9  = -0.00009 * x**5
     f.10 =  2.16E-12 * x**16  /* war 2.168; korrigiert lt. Original  */
     f.11 = -1.5E-28 * x**40
     f.12 =  2.0E-56 * x**80
     y = 0
     do i=1 to 12
          y = y + f.i
          end
     end
when x <= 5.34 then do         /* 6000 fps im Original; P(v) statt fR */
     y = 348.03735487 * RxCalcPower(x*1120,-0.80274201) * 0.75475
     end
otherwise
     y = 0                     /* Machzahl zu gro                    */
     end
return y * 0.6366198           /* Faktor fr -> cw nach MOLITZ/STROBEL */
/*--------------------------------------------------------------------*/
::ROUTINE UK_PROOF      PUBLIC
numeric digits 24
parse arg x
if x < 2 | x > 3.75 then y = 0
else do
  y=723.8462272317008030+x*(-2392.585151724759296+    ,
    x*(3490.751718146654992+x*(-2946.832357136780348+ ,
    x*(1586.961967665203628+x*(-565.5762202133796860+ ,
    x*(133.4281261597059632+x*(-20.09748296316034945+ ,
    x*(1.754143206228993279+x*-0.06760817810906892289))))))))
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE Z_CRANZ       PUBLIC
numeric digits 24
parse arg x
if x < 0.7 | x > 2.3 then return 0
x=x**2
y=(0.2700569589370984486+x*(0.8504426558566832254+ ,
  x*(-3.450007054228936318+x*(3.925885835020028465+ ,
  x*(-1.678292078747602917+x*0.2549381362568457290)))))/ ,
  (1.0+x*(-1.177143009189962986+x*(-0.8906037689738694266+ ,
  x*(2.225696964925263262+x*(-1.124816738741137968+ ,
  x*0.1835753730926895070)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE Z_KRUPP       PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
y=(0.6857467724470322313+x*(-0.2402052711573636123+ ,
  x*(-2.078469846236347414+x*(2.360695807319310262+ ,
  x*(-0.8732800428589367289+x*0.09708969685688712630)))))/ ,
  (1.0+x*(-1.834448391132976103+x*(0.5413329475934097334+ ,
  x*(0.5269571604529892595+x*(-0.3142757548201878884+ ,
  x*0.03932842809350855415)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE FTB_M118      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
x=1.0/x;
y=-87.72258003551794558+x*(1520.189734615481664+    ,
  x*(-11664.24805359562454+x*(52367.52857364068236+ ,
  x*(-152356.5574314779147+x*(300143.9486281213151+ ,
  x*(-405436.7446250552634+x*(370767.1284200317388+ ,
  x*(-219662.1837484407224+x*(76131.39160181069874+ ,
  x*-11722.36154623955618)))))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE FTB_190FMJ    PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
x = RxCalcLog(x)
y=(0.4036180948524891035+x*10.500156978397519820)/      ,
  (1.0+x*(23.39862651377555112+x*11.16774330347414840))
return y
/*--------------------------------------------------------------------*/
::ROUTINE VM_556        PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3 then return 0
x=x**2
y=(0.4107370953268219961+x*(-0.1482414878633308500+        ,
  x*0.04879128465998813843))/                              ,
  (1.0+x*(-0.5451571467225930531+x*0.2037546700413673232))
return y
/*--------------------------------------------------------------------*/
/* 16 Okt 2015                                                        */
/*--------------------------------------------------------------------*/
::ROUTINE 24C_ETBS      PUBLIC
numeric digits 24
parse arg x
if x < 0.92 | x > 3.0 then return 0
x = RxCalcLog(x)
y=(0.3635934769306640226+x*(7.493797694281824896+  ,
  x*(63.91844189465263554+x*(198.7879888836631642+ ,
  x*-148.2035840103539642))))/                     ,
  (1.0+x*(16.92406633827409757+x*(139.8152341006380252+ ,
  x*(501.1064864211320931+x*-214.5233637959281704))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE 32N_ETBS      PUBLIC
numeric digits 24
parse arg x
if x < 0.9 | x > 3.0 then return 0
y=(-0.3583274737772116407+x*(0.8544523343365283677+    ,
  x*(-0.2250947788402816782+x*(-0.6936997414270201796+ ,
  x*0.4230856211058435612))))/                         ,
  (1.0+x*(-5.144231571151369325+x*(9.960605040218977135+ ,
  x*(-8.525314705703694394+x*2.710158606552772458))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE 33D_ETBS      PUBLIC
numeric digits 24
parse arg x
if x < 0.9 | x > 3.0 then return 0
y=(1.776112512424098166+x*(-7.789093291683043252+        ,
  x*(13.11489201859111427+x*(-10.551914932399516378+     ,
  x*(4.062576899704274114+x*-0.6149866703881699066)))))/ ,
  (1.0+x*(-3.328312551942468224+x*(1.136240176372451144+ ,
  x*(6.599432510614846530+x*(-8.983282591507649405+      ,
  x*(4.306612381670935725+x*-0.7387604596873103000))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE 61_ETBS       PUBLIC
numeric digits 24
parse arg x
if x < 0.92 | x > 3.0 then return 0
y=(0.4209850413796693527+x*(-1.307958378416342401+   ,
  x*(1.427682897077377222+x*(-0.6396767053630652591+ ,
  x*0.10185217208790849347))))/                      ,
  (1.0+x*(-2.723836326732844598+x*(2.345322617305728369+ ,
  x*(-0.4924852160323243882+x*(-0.1862969285979671466+   ,
  x*0.06489453587738489469)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE M74_ETBS      PUBLIC
numeric digits 24
parse arg x
if x < 0.85 | x > 3.0 then return 0
y=(0.4926018607998267904+x*(-2.412562685268511034+   ,
  x*(4.653958368637776524+x*(-4.477531653790210878+  ,
  x*(2.232737342513008337+x*(-0.5363210543251389300+ ,
  x*0.04625815820632168474))))))/                    ,
  (1.0+x*(-4.856027472585817236+x*(9.031966895488152208+ ,
  x*(-8.055441320137639219+x*(3.457618267392867800+      ,
  x*(-0.5885882597293183008+x*0.007650546173541850342))))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE UNST2_G7      PUBLIC
parse arg x
select
when x < 0 then return 0
when x > 0.82 then do
     y = MCCOY_G7(x)
     end
otherwise
     y = 0.1844 * (0.82 - x)**2 + 0.126
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE UNST3_G7      PUBLIC
parse arg x
select
when x < 0 then return 0
when x > 0.82 then do
     y = MCCOY_G7(x)
     end
otherwise
     y = 0.3703 * (0.82 - x)**2 + 0.126
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE UNST4_G7      PUBLIC
parse arg x
select
when x < 0 then return 0
when x > 0.82 then do
     y = MCCOY_G7(x)
     end
otherwise
     y = 0.5562 * (0.82 - x)**2 + 0.126
     end
return y
/*--------------------------------------------------------------------*/
/* 13 Dez 2015                                                        */
/*--------------------------------------------------------------------*/
::ROUTINE L_B557        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x=x**2
y=(0.2579575105049482896+x*(-0.7599870029071184314+   ,
  x*(0.5012157622643953904+x*(0.02386917499722976179+ ,
  x*0.008589031338549718008))))/                      ,
  (1.0+x*(-2.410460138593318938+x*(1.371609776862015180+ ,
  x*(0.06871601845242528806+x*0.05003500966405122220))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N558        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
y=(-0.06381841771675575952+x*(0.2591030955848171604+       ,
  x*(-0.2077135225562080056+x*(-0.10126140094118846796+    ,
  x*(0.1525378457487708968+x*-0.03963203249608210626)))))/ ,
  (1.0+x*(-3.354925382579974401+x*(4.844578366742894284+   ,
  x*(-3.744344249145659015+x*(1.488673868037056306+        ,
  x*-0.2364111891816756386)))))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N559        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x = RxCalcSqrt(x)
y=(-4.319841748895419440+x*(10.78987629499962395+        ,
  x*(-8.117024652904773755+x*1.645105501783756207)))/    ,
  (1.0+x*(-4.210655841373490932+x*(6.825349309190478674+ ,
  x*-3.620369922159852025)))
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N560        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x = RxCalcLog(x)
y=(0.3360001709555874937+x*(75.79376282441996878+       ,
  x*(149.8587121905739679+x*-101.62384374275833305)))/  ,
  (1.0+x*(210.7748716520588616+x*(204.3841886198915443+ ,
  x*0.9974664022877415218)));
return y
/*--------------------------------------------------------------------*/
::ROUTINE L_N563        PUBLIC
numeric digits 24
parse arg x
if x < 1.0 | x > 3.0 then return 0
x1 = x
x2 = RxCalcLog(x)/x
x3 = 1/x
x4 = RxCalcExp(-x)
y=-65.47402793369583558+6.227954771832697459*x1    ,
  +54.56371444931777440*x2+97.81084585448115484*x3 ,
  -103.14263195704482436*x4
return y
/*--------------------------------------------------------------------*/
/* 19 Jan 2017                                                        */
/*--------------------------------------------------------------------*/
::ROUTINE 98D_ETBS      PUBLIC
numeric digits 24
parse arg x
select
when x < 0 then y = 0
when x > 3 then y = 0
when x >= 0.96 then do
     x=x**2
     y=(0.4111384350628869172+x*(-1.181279877675034691+       ,
       x*(1.219841083227998507+x*(-0.5839835395760597784+     ,
       x*0.1370374614319739322))))/                           ,
       (1.0+x*(-2.790412816167822281+x*(2.725650724848005787+ ,
       x*(-1.171600246508379411+x*(0.2133316042091703092+     ,
       x*0.03184034525025182760)))))
     end
otherwise     /* 0 <= Mach < 0.96 */
     y=(0.2048409514672317956+x*(-1.480861312155105307+       ,
       x*(4.197745969715546730+x*(-5.787002413860685592+      ,
       x*(3.883355451539845097+x*-1.018093713860753722)))))/  ,
       (1.0+x*(-7.226720607880672752+x*(20.48782365699229208+ ,
       x*(-28.26563486424287775+x*(18.99862662990468413+      ,
       x*-4.994450054011952050)))))
     y = y + 0.004854567 /* Erzeugt glatten cw-bergang bei Mach 0.96 */
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE 98DR_ETBS     PUBLIC
numeric digits 24
parse arg x
select
when x < 0.34 then y = 0
when x < 0.96 then do
     y=(0.2565550078258118763+x*(-2.210322986846460818+       ,
       x*(6.646319418506204502+x*(-9.210897914972648416+      ,
       x*(6.012223715224993426+x*-1.493732253553962218)))))/  ,
       (1.0+x*(-8.727249214194267970+x*(25.64673175777143383+ ,
       x*(-33.84822636874016130+x*(20.40300083692086507+      ,
       x*-4.470200482288953005)))))
     end
when x <= 3.0 then do
     y=(0.5545476608345962126+x*-0.5825801906098144506)/  ,
       (1.0+x*(-0.4962687452560860062+x*-0.5972198370113283054))
     y = y + 0.001532733 /* Erzeugt glatten cw-bergang bei Mach 0.96 */
       end
otherwise
     y = 0
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE 7RN_ETBS      PUBLIC
numeric digits 24
parse arg x
select
when x < 0.53 then y = 0
when x < 0.90 then do
  x=x**2
  y=-192.9650377579004515+x*(3678.033838803462906+    ,
    x*(-30528.72916420730361+x*(144700.0141812612008+ ,
    x*(-431133.2719203370264+x*(837533.0794229211673+ ,
    x*(-1061526.442421022059+x*(847318.0525810304544+ ,
    x*(-386994.6241760984998+x*77164.80279449476380))))))))
  y = y + 0.001169512    /* Erzeugt glatten cw-bergang bei Mach 0.90 */
  end
when x <= 3 then do
  x= RxCalcLog(x);
  y=(0.6171032130088999449+x*(7.759160245559093669+       ,
    x*(77.49074604720129770+x*(170.3852981731044557+      ,
    x*(522.9719984041408590+x*-395.2392872852340324)))))/ ,
    (1.0+x*(12.96130197414906941+x*(131.1343913314033077+ ,
    x*(425.3751786663297631+x*(773.9651474717170539+      ,
    x*-416.6102942364992127)))));
    end
otherwise
    y = 0
    end
return y
/*--------------------------------------------------------------------*/
::ROUTINE HFB_ETBS      PUBLIC
numeric digits 24
parse arg x
select
when x <  1.0 then y = 0
when x <= 3.2 then do
  x = x**2
  y=(-0.8824686496723495880+x*(7.935356088057109156+  ,
    x*(-11.81447991382683662+x*(3.679349558164068488+ ,
    x*1.141740048581695475))))/                       ,
    (1.0+x*(7.564859197144781374+x*(-9.884421032404562530+ ,
    x*(-5.676525899465507362+x*(7.089658773985625847+ ,
    x*0.08501335480951125887)))))
    end
otherwise
    y = 0
    end
return y
/*--------------------------------------------------------------------*/
/* 10 Apr 2017                                                        */
/*--------------------------------------------------------------------*/
::ROUTINE 46_VOLLM      PUBLIC
numeric digits 24
parse arg x
if x < 0 | x > 4 then y = 0
else do
     x=x**2
     y=(0.1561935854517296755+x*(-0.4993059645690534236+      ,
       x*(0.9656062811861527991+x*(-1.135402372307230552+     ,
       x*0.5696487189322385130))))/                           ,
       (1.0+x*(-2.781755609234262729+x*(4.129630001072871976+ ,
       x*(-3.572945055725177367+x*(1.326126920711061859+      ,
       x*0.05893519147055250446)))))
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE 46_STAHL      PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 4 then y = 0
else do
     x=RxCalcSqrt(x)
     y=(-0.2705790114444037786+x*(0.8319729911775170062+      ,
       x*(-0.8740496828170880254+x*0.3136337579322852878)))/  ,
       (1.0+x*(-3.690626140456973429+x*(5.283093060346462736+ ,
       x*(-3.511745452178849162+x*0.9216058727592100762))))
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE 46_ACTION     PUBLIC
numeric digits 24
parse arg x
if x < 1 | x > 3.5 then y = 0
else do
     x=1.0/x
     y=-11.91610834719097304+x*(256.8343723253903914+     ,
       x*(-2335.888223641385522+x*(12312.74163459118797+  ,
       x*(-41663.41782943807513+x*(94638.33219450608013+  ,
       x*(-146235.7050218901496+x*(151856.9589407815773+  ,
       x*(-101464.88798526860851+x*(39403.83835076138655+ ,
       x*-6756.462624053049237)))))))))
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE 46_TMZINN     PUBLIC
numeric digits 24
parse arg x
if x < 0 | x > 4 then y = 0
else do
     y=(0.2361930314454036073+x*(-0.9301253995211065060+        ,
       x*(1.531830872395155651+x*(-1.289878713515556868+        ,
       x*(0.5184523871892781948+x*-0.06207890203506644836)))))/ ,
       (1.0+x*(-3.664080152733131449+x*(5.448101042736438804+   ,
       x*(-4.047041893923393195+x*(1.431858229034938087+        ,
       x*-0.1588938819696675969)))))
     end
return y
/*--------------------------------------------------------------------*/
::ROUTINE FLECHETTE     PUBLIC
numeric digits 24
parse arg x
if x < 0.5 | x > 5.0 then y = 0
else do
     y=(0.3695038847138136155+x*(-0.4630698421644050480+      ,
       x*(0.01525423848797455090+x*(0.1129630320579271639+    ,
       x*0.01386978890231893253))))/                          ,
       (1.0+x*(-2.236148287148100471+x*(2.176787959456815594+ ,
       x*(-1.295907922129046151+x*(0.4481631665320024048+     ,
       x*-0.03230428293241956904)))))
       end
return y
/*--------------------------------------------------------------------*/
::ROUTINE SU_1956       PUBLIC
numeric digits 24
parse arg x
select
when x > 5.0 then y = 0
when x > 0.553 then do
     y=(0.3184733689288351214+x*(-0.9649968434276078493+  ,
       x*(1.202198603707920735+x*(-0.7379655028701153918+ ,
       x*0.1878667413631547675))))/                       ,
       (1.0+x*(-2.856000368901785689+x*(3.162215007520494750+ ,
       x*(-1.553112454174053262+x*(0.1999697540483586011+     ,
       x*0.06128190781964878587)))))
       end
when x >= 0.2 then y = 0.308
otherwise
     y = 0
     end
return y
/*--------------------------------------------------------------------*/
/*                       J P _ L W L I S T E                          */
/*   Liste der implementierten Luftwiderstandsmodelle zurckmelden    */
/*   (ohne drei Spezialmodelle UNSTx_G7)                              */
/*--------------------------------------------------------------------*/
::ROUTINE JP_LWLISTE    PUBLIC          /* gltig im   */
use arg modname. , modrange.            /* Machbereich */
modname.1   = '2_4_CRH'    ; modrange.1   = '1.0 ... 3.0'
modname.2   = '2_CRH'      ; modrange.2   = '1.0 ... 3.0'
modname.3   = '5_10_CRH'   ; modrange.3   = '1.0 ... 3.0'
modname.4   = '8_16_CRH'   ; modrange.4   = '1.0 ... 3.0'
modname.5   = 'BRL620_M2'  ; modrange.5   = '0.5 ... 3.0'
modname.6   = 'BURGSDORFF' ; modrange.6   = '0.76... 3.0'
modname.7   = 'CARTER_CUBE'; modrange.7   = '0.0 ...10.0'
modname.8   = 'CARTER_SPH' ; modrange.8   = '0.0 ...10.0'
modname.9   = 'CETMEIWK'   ; modrange.9   = '0.87... 2.58'
modname.10  = 'CW_CONST'   ; modrange.10  = '0.0 ...10.0'
modname.11  = 'DEMOGUE'    ; modrange.11  = '0.0 ... 3.52'
modname.12  = 'DUPUIS_040' ; modrange.12  = '1.0 ... 5.62'
modname.13  = 'DUPUIS_140' ; modrange.13  = '1.0 ... 5.62'
modname.14  = 'DUPUIS_240' ; modrange.14  = '1.0 ... 5.62'
modname.15  = 'FMV_10PRJ'  ; modrange.15  = '1.0 ... 3.0'
modname.16  = 'FORTR_G6'   ; modrange.16  = '0.0 ... 5.0'
modname.17  = 'GAVRE_G1'   ; modrange.17  = '0.0 ... 3.22'
modname.18  = 'GP11'       ; modrange.18  = '1.0 ... 3.0'
modname.19  = 'GP11_4102'  ; modrange.19  = '1.0 ... 3.0'
modname.20  = 'GP11_K'     ; modrange.20  = '1.0 ... 3.0'
modname.21  = 'HODSOCK'    ; modrange.21  = '1.0 ... 3.57'
modname.22  = 'KUTTERER'   ; modrange.22  = '1.0 ... 3.0'
modname.23  = 'L_AP485'    ; modrange.23  = '1.0 ... 3.0'
modname.24  = 'L_AP492'    ; modrange.24  = '1.0 ... 3.0'
modname.25  = 'L_AP529'    ; modrange.25  = '1.0 ... 3.0'
modname.26  = 'L_AP529N'   ; modrange.26  = '1.0 ... 3.0'
modname.27  = 'L_API526'   ; modrange.27  = '1.0 ... 3.0'
modname.28  = 'L_B408'     ; modrange.28  = '1.0 ... 3.0'
modname.29  = 'L_B466'     ; modrange.29  = '1.0 ... 3.0'
modname.30  = 'L_B476'     ; modrange.30  = '1.0 ... 3.0'
modname.31  = 'L_BULLEXN'  ; modrange.31  = '1.0 ... 3.0'
modname.32  = 'L_BULLEX2'  ; modrange.32  = '1.0 ... 3.0'
modname.33  = 'L_D166'     ; modrange.33  = '1.0 ... 3.0'
modname.34  = 'L_D46'      ; modrange.34  = '1.0 ... 3.0'
modname.35  = 'L_E539'     ; modrange.35  = '1.0 ... 3.0'
modname.36  = 'L_G490'     ; modrange.36  = '1.0 ... 3.0'
modname.37  = 'L_GB422'    ; modrange.37  = '1.0 ... 3.0'
modname.38  = 'L_GB432'    ; modrange.38  = '1.0 ... 3.0'
modname.39  = 'L_GB458'    ; modrange.39  = '1.0 ... 3.0'
modname.40  = 'L_GB478'    ; modrange.40  = '1.0 ... 3.0'
modname.41  = 'L_GB488'    ; modrange.41  = '1.0 ... 3.0'
modname.42  = 'L_GB491'    ; modrange.42  = '1.0 ... 3.0'
modname.43  = 'L_GB493'    ; modrange.43  = '1.0 ... 3.0'
modname.44  = 'L_GB501'    ; modrange.44  = '1.0 ... 3.0'
modname.45  = 'L_GB527'    ; modrange.45  = '1.0 ... 3.0'
modname.46  = 'L_GB528'    ; modrange.46  = '1.0 ... 3.0'
modname.47  = 'L_GB541'    ; modrange.47  = '1.0 ... 3.0'
modname.48  = 'L_GB543'    ; modrange.48  = '1.0 ... 3.0'
modname.49  = 'L_GB546'    ; modrange.49  = '1.0 ... 3.0'
modname.50  = 'L_GB547'    ; modrange.50  = '1.0 ... 3.0'
modname.51  = 'L_GB550'    ; modrange.51  = '1.0 ... 3.0'
modname.52  = 'L_N505'     ; modrange.52  = '1.0 ... 3.0'
modname.53  = 'L_N508'     ; modrange.53  = '1.0 ... 3.0'
modname.54  = 'L_N518'     ; modrange.54  = '1.0 ... 3.0'
modname.55  = 'L_N522'     ; modrange.55  = '1.0 ... 3.0'
modname.56  = 'L_S374'     ; modrange.56  = '1.0 ... 3.0'
modname.57  = 'L_S405'     ; modrange.57  = '1.0 ... 3.0'
modname.58  = 'L_S538'     ; modrange.58  = '1.0 ... 3.0'
modname.59  = 'LOWRY'      ; modrange.59  = '1.0 ... 5.0'
modname.60  = 'LW2'        ; modrange.60  = '0.1 ...10.0'
modname.61  = 'M855_WEIN'  ; modrange.61  = '1.0 ... 3.0'
modname.62  = 'MAYEVSAB'   ; modrange.62  = '0.0 ... 3.0'
modname.63  = 'MCCOY_G2'   ; modrange.63  = '1.0 ... 3.0'
modname.64  = 'MCCOY_G5'   ; modrange.64  = '0.0 ... 3.0'
modname.65  = 'MCCOY_G6'   ; modrange.65  = '1.0 ... 3.0'
modname.66  = 'MCCOY_G7'   ; modrange.66  = '0.0 ... 5.0'
modname.67  = 'MCCOY_G8'   ; modrange.67  = '0.0 ... 5.0'
modname.68  = 'MCCOY_M2'   ; modrange.68  = '1.0 ... 3.0'
modname.69  = 'MCCOY_SPH'  ; modrange.69  = '0.0 ... 4.0'
modname.70  = 'NAVPG'      ; modrange.70  = '1.0 ... 3.22'
modname.71  = 'NL_1898'    ; modrange.71  = '0.0 ... 3.0'
modname.72  = 'POWER_3_2'  ; modrange.72  = '1.0 ...10.0'
modname.73  = 'RWS_1943'   ; modrange.73  = '1.0 ... 3.0'
modname.74  = 'S_CRANZ'    ; modrange.74  = '1.0 ... 3.0'
modname.75  = 'SCHAPIRO'   ; modrange.75  = '0.0 ... 5.0'
modname.76  = 'SIACCI'     ; modrange.76  = '0.0 ... 3.52'
modname.77  = 'SU_1943'    ; modrange.77  = '1.0 ... 3.0'
modname.78  = 'UK_1910'    ; modrange.78  = '0.0 ... 4.46'
modname.79  = 'UK_1940'    ; modrange.79  = '0.0 ... 5.34'
modname.80  = 'UK_PROOF'   ; modrange.80  = '2.0 ... 3.75'
modname.81  = 'Z_CRANZ'    ; modrange.81  = '0.7 ... 2.3'
modname.82  = 'Z_KRUPP'    ; modrange.82  = '1.0 ... 3.0'
modname.83  = 'FTB_M118'   ; modrange.83  = '1.0 ... 3.0'
modname.84  = 'FTB_190FMJ' ; modrange.84  = '1.0 ... 3.0'
modname.85  = 'VM_556'     ; modrange.85  = '1.0 ... 3.0'
modname.86  = 'L_GB551'    ; modrange.86  = '1.0 ... 3.0'
modname.87  = 'L_GB553'    ; modrange.87  = '1.0 ... 3.0'
modname.88  = 'L_GB554'    ; modrange.88  = '1.0 ... 3.0'
modname.89  = '24C_ETBS'   ; modrange.89  = '0.92... 3.0'
modname.90  = '32N_ETBS'   ; modrange.90  = '0.9 ... 3.0'
modname.91  = '33D_ETBS'   ; modrange.91  = '0.9 ... 3.0'
modname.92  = '61_ETBS'    ; modrange.92  = '0.92... 3.0'
modname.93  = 'M74_ETBS'   ; modrange.93  = '0.85... 3.0'
modname.94  = 'L_B557'     ; modrange.94  = '1.0 ... 3.0'
modname.95  = 'L_N558'     ; modrange.95  = '1.0 ... 3.0'
modname.96  = 'L_N559'     ; modrange.96  = '1.0 ... 3.0'
modname.97  = 'L_N560'     ; modrange.97  = '1.0 ... 3.0'
modname.98  = 'L_N563'     ; modrange.98  = '1.0 ... 3.0'
modname.99  = '98D_ETBS'   ; modrange.99  = '0.0 ... 3.0'
modname.100 = '98DR_ETBS'  ; modrange.100 = '0.34... 3.0'
modname.101 = '7RN_ETBS'   ; modrange.101 = '0.53... 3.0'
modname.102 = 'HFB_ETBS'   ; modrange.102 = '1.0 ... 3.2'
modname.103 = '46_VOLLM'   ; modrange.103 = '0.0 ... 4.0'
modname.104 = '46_STAHL'   ; modrange.104 = '1.0 ... 4.0'
modname.105 = '46_ACTION'  ; modrange.105 = '1.0 ... 4.0'
modname.106 = '46_TMZINN'  ; modrange.106 = '0.0 ... 4.0'
modname.107 = 'FLECHETTE'  ; modrange.107 = '0.5 ... 5.0'
modname.108 = 'SU_1956'    ; modrange.108 = '0.2 ... 5.0'
modname.0   = 108          ; modrange.0  = 108
return 'JP_LWMod  V4.13  Stand: 2017-08-03'
/*--------------------------------------------------------------------*/
/*                       J P _ L W U L I S T                          */
/* Teilliste von Modellen die sich fr den Unterschallbereich eignen  */
/*--------------------------------------------------------------------*/
::ROUTINE JP_LWULIST    PUBLIC          /* gltig im   */
use arg modname. , modrange.            /* Machbereich */
modname.1  = 'BRL620_M2'  ; modrange.1  = '0.5 ... 3.0'
modname.2  = 'DEMOGUE'    ; modrange.2  = '0.0 ... 3.52'
modname.3  = 'FORTR_G6'   ; modrange.3  = '0.0 ... 5.0'
modname.4  = 'GAVRE_G1'   ; modrange.4  = '0.0 ... 3.22'
modname.5  = 'LW2'        ; modrange.5  = '0.1 ...10.0'
modname.6  = 'MAYEVSAB'   ; modrange.6  = '0.0 ... 3.0'
modname.7  = 'MCCOY_G5'   ; modrange.7  = '0.0 ... 3.0'
modname.8  = 'MCCOY_G7'   ; modrange.8  = '0.0 ... 5.0'
modname.9  = 'MCCOY_G8'   ; modrange.9  = '0.0 ... 5.0'
modname.10 = 'SCHAPIRO'   ; modrange.10 = '0.0 ... 5.0'
modname.11 = 'SIACCI'     ; modrange.11 = '0.0 ... 3.52'
modname.12 = 'UK_1910'    ; modrange.12 = '0.0 ... 4.46'
modname.13 = 'UK_1940'    ; modrange.13 = '0.0 ... 5.34'
modname.14 = 'UNST2_G7'   ; modrange.14 = '0.0 ... 5.0'
modname.15 = 'UNST3_G7'   ; modrange.15 = '0.0 ... 5.0'
modname.16 = 'UNST4_G7'   ; modrange.16 = '0.0 ... 5.0'
modname.17 = '98D_ETBS'   ; modrange.17 = '0.0 ... 3.0'
modname.18 = '46_VOLLM'   ; modrange.18 = '0.0 ... 4.0'
modname.19 = '46_TMZINN'  ; modrange.18 = '0.0 ... 4.0'
modname.20 = 'SU_1956'    ; modrange.20 = '0.2 ... 5.0'
modname.0  = 20           ; modrange.0  = 20
return 'JP_LWMod  V4.13  Stand: 2017-08-03'
